#pragma once

#define MSG_RECEIVE_CHECK		_T("WOOSIM_PRT_OK")

#define DATA					0x44		// Response data from printer (ex. card data , model name, etc)
#define STATUS_ANSWER			0x53		// Response of printer status request

//Return Message
#define SUCCESS									 1
#define ALREADY_OPENED							-1
#define NO_RESPONSE_FROM_PRINTER				-5
#define TIMEOUT									-7
#define NOT_OPEN_THE_PORT						-11

//Serial, Bluetooth Err message
#define UNABLE_TO_OPEN_THE_PORT					-2
#define UNABLE_TO_CONFIGURE_THE_SERIAL_PORT		-3 
#define UNABLE_TO_SET_THE_TIMEOUT_PARAMETERS	-4

//Wireless Err message
#undef SOCKET_ERROR
#define SOCKET_ERROR							-2
#define CONNECT_FAIL							-3

//barcode type
#define UPCA									65
#define UPCE									66
#define EAN13									67
#define EAN8									68
#define CODE39									69
#define ITF										70
#define CODABAR									71
#define CODE93									72
#define CODE128									73

//printer width (dot unit)
#define _1INCH									192
#define _2INCH									384
#define _3INCH									576
#define _4INCH									832

//MCU version
#define MCU_M16C								0
#define MCU_ARM									1
#define MCU_RX									2


/******************************************************************************************
	DLL export/import functions
******************************************************************************************/
#ifdef DLL_EXPORT
#define DLL_API __declspec(dllexport)
#else
#define DLL_API __declspec(dllimport)
#endif

// Device communication API
extern "C" DLL_API int  ConnectSerialPrinter(TCHAR *portName, int baudRate=57600,int timeoutMsec=1000, BOOL bProtocol=FALSE);
extern "C" DLL_API int  ConnectWirelessPrinter(TCHAR *ipAddress, int port, int timeoutMsec=5000, BOOL bProtocol=FALSE);
extern "C" DLL_API BOOL ClosePrinterConnection();
// Send directly command to device without using printing data buffer
extern "C" DLL_API void EnterMSRMode(int n);
extern "C" DLL_API void CancelMSRMode();
extern "C" DLL_API void EnterSCRMode();
extern "C" DLL_API void CancelSCRMode();
// Require information from device without using printing data buffer
extern "C" DLL_API void GetPrinterModelName();
extern "C" DLL_API void GetFirmwareVersion();
extern "C" DLL_API int  GetPrinterStatus(int timeoutMsec);
extern "C" DLL_API int  GetPrinterStatusEx(int timeoutMsec);

// Printing data buffer handling
extern "C" DLL_API int  PrintSpool(BOOL bDelete=TRUE);
extern "C" DLL_API void ClearSpool();

// Append command & data to the printing data buffer
extern "C" DLL_API int  ControlCommand(BYTE *data, int length);
extern "C" DLL_API void TextSaveSpool(TCHAR *text);
extern "C" DLL_API void InitPrinterStatus();
extern "C" DLL_API void PrintData();
extern "C" DLL_API void PrintDotFeed(int dots);
extern "C" DLL_API void PrintLineFeed(int lines);
extern "C" DLL_API void SetCharCodeTable(int n, int mcu);
extern "C" DLL_API void SetFontSize(int n);
extern "C" DLL_API void SetTextAlignment(int n);
extern "C" DLL_API void SetTextStyle(int underline, BOOL bold, int width, int height, BOOL reverse);
extern "C" DLL_API void InitLineSpace();
extern "C" DLL_API void SetLineSpace(int n);
extern "C" DLL_API void SetAbsPosition(int distance);
extern "C" DLL_API void SetCharSpace(int n);
extern "C" DLL_API void SetUpsideDown(BOOL set);
extern "C" DLL_API void SetFontForTTF(TCHAR *ttfFile);
extern "C" DLL_API int  PrintSpoolForTTF(TCHAR* data, BYTE fontWidth, BYTE fontHeight);
extern "C" DLL_API void SetPositionFromMark(int distance);
extern "C" DLL_API void FeedToMark();
extern "C" DLL_API void CutPaper(int mode);
// Page mode
extern "C" DLL_API void SetPageMode();
extern "C" DLL_API void InitPageMode(int x, int y, int width, int height);
extern "C" DLL_API void Page_DrawLine(int x1, int y1, int x2, int y2, int thickness);
extern "C" DLL_API void Page_DrawBox(int x, int y, int width, int height, int thickness);
extern "C" DLL_API void Page_DrawEllipse(int x, int y, int radiusW, int radiusH, int thickness);
extern "C" DLL_API void Page_DotFeed(int dots);
extern "C" DLL_API void Page_LineFeed(int lines);
extern "C" DLL_API void Page_Newline();
extern "C" DLL_API void Page_ClearCurrentData();
extern "C" DLL_API void Page_SetArea(int x, int y, int width, int height);
extern "C" DLL_API void Page_SetDirection(int n);
extern "C" DLL_API void Page_SetPosition(int x, int y);
extern "C" DLL_API void Page_Print();
extern "C" DLL_API void Page_SetStandardMode();
extern "C" DLL_API void Page_Print_StandardMode();
// Image
extern "C" DLL_API void NormalBmpSaveSpool(TCHAR* bmpFilePath);
extern "C" DLL_API void CompressedBmpSaveSpool(TCHAR *bmpFilePath);
extern "C" DLL_API void LoadLogoSaveSpool(int n);
// Barcode 
extern "C" DLL_API void OneDimensionBarcodeSaveSpool(BYTE barcodeType, int width, int height, BOOL bHri, TCHAR *barcodeData);
extern "C" DLL_API void PDF417SaveSpool(int width, int column, int level, int ratio, TCHAR *barcodeData, BOOL bHri);
extern "C" DLL_API void DataMatrixSaveSpool(int height, int width, int module, TCHAR *barcodeData);
extern "C" DLL_API void QRCodeSaveSpool(int version, TCHAR level, int module, TCHAR *barcodeData);
extern "C" DLL_API void MicroPDF417SaveSpool(int width, int column, int row, int ratio, TCHAR *barcodeData, BOOL bHri);
extern "C" DLL_API void TruncatedPDF417SaveSpool(int width, int column, int level, int ratio, TCHAR *barcodeData, BOOL bHri);
extern "C" DLL_API void MaxicodeSaveSpool(int mode, TCHAR *barcodeData);
extern "C" DLL_API void GS1DatabarSaveSpool(int type, int n, TCHAR *barcodeData);
